==> fltk-docs-1.3.3-4-aarch64.pkg.tar.xz: usr/share/doc/fltk/navtreedata.js <==
var NAVTREE =
[
  [ "FLTK 1.3.3", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", null, [
      [ "Class List", "annotated.html", "annotated" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aa776cf3129e97140c88a062881a2d29a",
"Fl__Return__Button_8H_source.html",
"classFl__Browser__.html#ac54a04415069ec232db034c283476572",
"classFl__File__Chooser.html#a13d55aea2af92464a98f396d679115d7",
"classFl__Graphics__Driver.html#a5b4765a8040427f7586bff03b49e80ee",
"classFl__Input__.html#a54d355077e57e9901a775ea968c39963",
"classFl__Paged__Device.html#aea57eda0ffa5353c7e678a17675681d4a1a399f1a5fcf30ae2853a91bf0820428",
"classFl__Preferences_1_1Node.html#ac7dada4e7b034b1cb6e7cfd1f6f60878",
"classFl__System__Printer.html#a5e5cb0bc76f33899d12a32762151088a",
"classFl__Text__Buffer.html#ad78c9dd21ff3fc04060114ddc1448803",
"classFl__Timer.html",
"classFl__Tree__Item.html#afa951d403d14800a3fcf22ec3df2a33f",
"classFl__Widget.html#ab2b89e03832a172d7648dabe0910b038",
"events.html#events_fl_dnd_enter",
"functions_func_s.html",
"group__fl__attributes.html#gae68ad6c3474fb71b3db5a44658b60b14",
"group__fl__events.html#ga08ba811a19462788094768ed98798120",
"intro.html#intro_visualcpp",
"structFl__Preferences_1_1Entry.html#a2b051afa655fd1ed856599fd114a12cd"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> fltk-docs-1.3.3-6-aarch64.pkg.tar.xz: usr/share/doc/fltk/navtreedata.js <==
var NAVTREE =
[
  [ "FLTK 1.3.3", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3aa776cf3129e97140c88a062881a2d29a",
"Fl__Return__Button_8H_source.html",
"classFl__Browser__.html#ac54a04415069ec232db034c283476572",
"classFl__File__Chooser.html#a13d55aea2af92464a98f396d679115d7",
"classFl__Graphics__Driver.html#a5b4765a8040427f7586bff03b49e80ee",
"classFl__Input__.html#a54d355077e57e9901a775ea968c39963",
"classFl__Paged__Device.html#aea57eda0ffa5353c7e678a17675681d4a1a399f1a5fcf30ae2853a91bf0820428",
"classFl__Preferences_1_1Node.html#ac7dada4e7b034b1cb6e7cfd1f6f60878",
"classFl__System__Printer.html#a5e5cb0bc76f33899d12a32762151088a",
"classFl__Text__Buffer.html#ad78c9dd21ff3fc04060114ddc1448803",
"classFl__Timer.html",
"classFl__Tree__Item.html#afa951d403d14800a3fcf22ec3df2a33f",
"classFl__Widget.html#ab2b89e03832a172d7648dabe0910b038",
"events.html#events_fl_dnd_enter",
"functions_func_p.html",
"group__fl__attributes.html#gae68ad6c3474fb71b3db5a44658b60b14",
"group__fl__events.html#ga08ba811a19462788094768ed98798120",
"intro.html#intro_visualcpp",
"structFl__Preferences_1_1Entry.html#a2b051afa655fd1ed856599fd114a12cd"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
